@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.44 2004/01/25 20:01:12 chpe Exp $
+ *  $Id: ephy-history.c,v 1.46.6.1 2004/05/20 18:04:57 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -133,7 +133,7 @@ ephy_history_set_property (GObject *object,
 			   const GValue *value,
 			   GParamSpec *pspec)
 {
-	EphyHistory *history = EPHY_HISTORY (history);
+	EphyHistory *history = EPHY_HISTORY (object);
 
 	switch (prop_id)
 	{
@@ -149,7 +149,7 @@ ephy_history_get_property (GObject *object,
 			   GValue *value,
 			   GParamSpec *pspec)
 {
-	EphyHistory *history = EPHY_HISTORY (history);
+	EphyHistory *history = EPHY_HISTORY (object);
 
 	switch (prop_id)
 	{
@@ -231,7 +231,7 @@ remove_obsolete_pages (EphyHistory *eb)
         g_date_set_time (&current_date, time (NULL));
 
 	children = ephy_node_get_children (eb->priv->pages);
-	for (i = 0; i < children->len; i++)
+	for (i = children->len -1; i >= 0; i--)
 	{
 		EphyNode *kid;
 
@@ -301,6 +301,7 @@ hosts_removed_cb (EphyNode *node,
 static void
 hosts_changed_cb (EphyNode *node,
 		  EphyNode *child,
+		  guint property_id,
 		  EphyHistory *eb)
 {
 	eb->priv->dirty = TRUE;
@@ -333,6 +334,7 @@ pages_removed_cb (EphyNode *node,
 static void
 pages_changed_cb (EphyNode *node,
 		  EphyNode *child,
+		  guint property_id,
 		  EphyHistory *eb)
 {
 	eb->priv->dirty = TRUE;
