@@ -15,12 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.h,v 1.14 2004/03/01 00:58:50 marco Exp $
+ *  $Id: ContentHandler.h,v 1.14.4.3 2004/08/31 12:32:53 chpe Exp $
  */
 
 #ifndef __ContentHandler_h
 #define __ContentHandler_h
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-embed-shell.h"
 
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
@@ -82,7 +86,11 @@ class GContentHandler : public nsIHelperAppLauncherDialog
 	nsCOMPtr<nsIFile> mTempFile;
 	nsCOMPtr<nsISupports> mContext;
 
-	char *mMimeType;	
+#if MOZILLA_SNAPSHOT < 20
+	char *mMimeType;
+#else
+	nsCString mMimeType;
+#endif	
 	PRBool mAppSupportScheme;
 	GnomeVFSMimeApplication *mHelperApp;
 	ContentAction mAction;
