@@ -1,11 +1,12 @@
 #include <nsIPrintSettings.h>
 #include <nsIDOMWindow.h>
 
-#include "ephy-embed.h"
+#include "print-dialog.h"
 
 GtkWidget *MozillaFindEmbed	(nsIDOMWindow *aDOMWindow);
 
 GtkWidget *MozillaFindGtkParent (nsIDOMWindow *aDOMWindow);
 
 NS_METHOD MozillaCollatePrintSettings (const EmbedPrintInfo *info,
-				       nsIPrintSettings *settings);
+				       nsIPrintSettings *settings,
+				       gboolean preview);
