@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.31.4.1 2004/05/03 19:07:06 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp,v 1.31.4.4 2004/07/25 11:12:30 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,6 +38,7 @@
 #include <nsIHistoryEntry.h>
 #include <nsISHEntry.h>
 #include <nsIDocumentEncoder.h>
+#include <nsIDocument.h>
 
 static void
 mozilla_embed_persist_class_init (MozillaEmbedPersistClass *klass);
@@ -137,9 +138,9 @@ impl_save (EphyEmbedPersist *persist)
 	long max_size;
 	EphyEmbed *embed;
 	EmbedPersistFlags flags;
-	PRUint32 persistFlags = 0;
+	EphyEmbedSingle *single;
 
-	/* FIXME implement max size */
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
 
 	g_object_ref (persist);
 	
@@ -158,6 +159,9 @@ impl_save (EphyEmbedPersist *persist)
 	if (embed)
 	{
 		browser = (EphyBrowser *) _mozilla_embed_get_ephy_browser (MOZILLA_EMBED(embed));
+
+		g_object_unref (embed);
+
 		NS_ENSURE_TRUE (browser, FALSE);
 	}
 	/* we must have one of uri or browser */
@@ -167,8 +171,8 @@ impl_save (EphyEmbedPersist *persist)
 	char *tmp_filename, *base;
 	base = g_build_filename (g_get_tmp_dir (), "sav-XXXXXX", NULL);
 	tmp_filename = ephy_file_tmp_filename (base, "html");
-	if (tmp_filename == NULL) return FALSE;
 	g_free (base);
+	if (tmp_filename == NULL) return FALSE;
 
 	nsCOMPtr<nsILocalFile> tmpFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
 	tmpFile->InitWithNativePath (nsDependentCString (tmp_filename));
@@ -246,7 +250,7 @@ impl_save (EphyEmbedPersist *persist)
 
 		EphyHeaderSniffer* sniffer = new EphyHeaderSniffer
 			(webPersist, MOZILLA_EMBED_PERSIST (persist),
-			 tmpFile, inURI, DOMDocument, postData);
+			 tmpFile, inURI, DOMDocument, postData, single);
 		if (!sniffer) return FALSE;
  
 		webPersist->SetProgressListener(sniffer);
