@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.31.4.2 2004/04/18 14:17:07 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.31.4.5 2004/06/29 12:39:28 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -584,9 +584,10 @@ set_combo_box_from_value (PropertyInfo *info, const  GValue *value)
 		}
 		else
 		{
+			char *v;
 			gtk_combo_box_set_active (GTK_COMBO_BOX (info->widget), -1);
 
-			char *v = g_strdup_value_contents (value);
+			v = g_strdup_value_contents (value);
 			g_warning ("Value '%s' not found in model for combo %s\n", v, info->id);
 			g_free (v);
 		}
@@ -751,12 +752,16 @@ set_pref_from_info_and_emit (PropertyInfo *info)
 static void
 togglebutton_clicked_cb (GtkWidget *widget, PropertyInfo *info)
 {
+	info->sane_state = TRUE;
+
 	set_pref_from_info_and_emit (info);
 }
 
 static void
 radiobutton_clicked_cb (GtkWidget *widget, PropertyInfo *info)
 {
+	info->sane_state = TRUE;
+
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget)))
 	{
 		return;
@@ -791,6 +796,8 @@ spinbutton_timeout_cb (PropertyInfo *info)
 		 * and set in the pref. Otherwise the old value is used */
 		gtk_spin_button_update (GTK_SPIN_BUTTON (info->widget));
 
+		info->sane_state = TRUE;
+
 		set_pref_from_info_and_emit (info);
 
 		/* done, don't run again */
@@ -827,6 +834,8 @@ spinbutton_changed_cb (GtkWidget *widget, PropertyInfo *info)
 static void
 changed_cb (GtkWidget *widget, PropertyInfo *info)
 {
+	info->sane_state = TRUE;
+
 	set_pref_from_info_and_emit (info);
 }
 
@@ -1182,7 +1191,7 @@ ephy_dialog_construct (EphyDialog *dialog,
 		       const char *domain)
 {
 	EphyDialogClass *klass = EPHY_DIALOG_GET_CLASS (dialog);
-	return klass->construct (dialog, properties, file, name, domain);
+	klass->construct (dialog, properties, file, name, domain);
 }
 
 void
