@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.37 2004/02/11 14:38:55 marco Exp $
+ *  $Id: ephy-topic-action.c,v 1.37.4.1 2004/06/14 21:26:57 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -343,7 +343,7 @@ sort_topics (gconstpointer a, gconstpointer b)
 static GtkWidget *
 build_topics_menu (EphyTopicAction *action, EphyNode *node)
 {
-	GtkWidget *menu, *item, *label;
+	GtkWidget *menu, *item;
 	GPtrArray *children;
 	int i;
 	EphyBookmarks *bookmarks;
@@ -388,9 +388,6 @@ build_topics_menu (EphyTopicAction *action, EphyNode *node)
 
 		item = gtk_image_menu_item_new_with_label (title);
 
-		label = gtk_bin_get_child (GTK_BIN (item));
-		gtk_label_set_use_markup  (GTK_LABEL (label), TRUE);
-
 		gtk_widget_show (item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
