@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +15,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-tab.h,v 1.15 2004/02/24 17:43:48 chpe Exp $
  */
 
 #ifndef EPHY_TAB_H
@@ -21,8 +24,7 @@
 
 #include "ephy-embed.h"
 
-#include <glib-object.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtkbin.h>
 
 G_BEGIN_DECLS
 
@@ -33,15 +35,15 @@ G_BEGIN_DECLS
 #define EPHY_IS_TAB_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_TAB))
 #define EPHY_TAB_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_TAB, EphyTabClass))
 
-typedef struct EphyTabClass EphyTabClass;
-typedef struct EphyTab EphyTab;
-typedef struct EphyTabPrivate EphyTabPrivate;
+typedef struct EphyTabClass	EphyTabClass;
+typedef struct EphyTab		EphyTab;
+typedef struct EphyTabPrivate	EphyTabPrivate;
 
 typedef enum
 {
 	TAB_NAV_UP	= 1 << 0,
 	TAB_NAV_BACK	= 1 << 1,
-	TAB_NAV_FORWARD	= 1 << 2,
+	TAB_NAV_FORWARD	= 1 << 2
 } TabNavigationFlags;
 
 typedef enum
@@ -53,13 +55,15 @@ typedef enum
 
 struct EphyTab
 {
-        GObject parent;
-        EphyTabPrivate *priv;
+	GtkBin parent;
+
+	/*< private >*/
+	EphyTabPrivate *priv;
 };
 
 struct EphyTabClass
 {
-	GObjectClass parent_class;
+	GtkBinClass parent_class;
 };
 
 /* Include the header down here to resolve circular dependency */
@@ -73,6 +77,8 @@ GObject                *ephy_tab_get_action		(EphyTab *tab);
 
 EphyEmbed              *ephy_tab_get_embed		(EphyTab *tab);
 
+EphyTab		       *ephy_tab_for_embed		(EphyEmbed *embed);
+
 void			ephy_tab_set_window		(EphyTab *tab,
 							 EphyWindow *window);
 
