@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu.c,v 1.22 2004/01/01 22:57:16 chpe Exp $
+ *  $Id: ephy-tabs-menu.c,v 1.24.4.1 2004/04/13 20:36:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,10 +38,6 @@
 
 #define MAX_LABEL_LENGTH 30
 
-/**
- * Private data
- */
-
 #define EPHY_TABS_MENU_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TABS_MENU, EphyTabsMenuPrivate))
 
 struct _EphyTabsMenuPrivate
@@ -51,9 +47,6 @@ struct _EphyTabsMenuPrivate
 	guint ui_id;
 };
 
-/**
- * Private functions, only availble from this file
- */
 static void	ephy_tabs_menu_class_init	(EphyTabsMenuClass *klass);
 static void	ephy_tabs_menu_init	  	(EphyTabsMenu *menu);
 
@@ -63,10 +56,6 @@ enum
 	PROP_WINDOW
 };
 
-/**
- * EphyTabsMenu object
- */
-
 GType
 ephy_tabs_menu_get_type (void)
 {
@@ -96,28 +85,30 @@ ephy_tabs_menu_get_type (void)
 }
 
 static void
-tab_added_cb (EphyNotebook *notebook, EphyEmbed *embed, EphyTabsMenu *menu)
+tab_added_cb (EphyNotebook *notebook, EphyTab *tab, EphyTabsMenu *menu)
 {
-	EphyTab *tab;
 	GtkAction *action;
+	char accel_path[40];
 
-        g_return_if_fail (EPHY_IS_EMBED (embed));
-	tab = ephy_tab_for_embed (embed);
+        g_return_if_fail (EPHY_IS_TAB (tab));
 
 	action = GTK_ACTION (ephy_tab_get_action (tab));
+
+	g_snprintf (accel_path, sizeof (accel_path),
+		    "<Actions>/TabsActions/%s", gtk_action_get_name (action));
+	gtk_action_set_accel_path (action, accel_path);
+
 	gtk_action_group_add_action (menu->priv->action_group, action);
 
 	ephy_tabs_menu_update (menu);
 }
 
 static void
-tab_removed_cb (EphyNotebook *notebook, EphyEmbed *embed, EphyTabsMenu *menu)
+tab_removed_cb (EphyNotebook *notebook, EphyTab *tab, EphyTabsMenu *menu)
 {
-	EphyTab *tab;
 	GtkAction *action;
                                                                                                                              
-        g_return_if_fail (EPHY_IS_EMBED (embed));
-	tab = ephy_tab_for_embed (embed);
+        g_return_if_fail (EPHY_IS_TAB (tab));
 
 	action = GTK_ACTION (ephy_tab_get_action (tab));
 	gtk_action_group_remove_action (menu->priv->action_group, action);
@@ -125,6 +116,12 @@ tab_removed_cb (EphyNotebook *notebook, EphyEmbed *embed, EphyTabsMenu *menu)
 	ephy_tabs_menu_update (menu);
 }
 
+static void
+tabs_reordered_cb (EphyNotebook *notebook, EphyTabsMenu *menu)
+{
+	ephy_tabs_menu_update (menu);
+}
+
 static void
 ephy_tabs_menu_set_window (EphyTabsMenu *menu, EphyWindow *window)
 {
@@ -143,6 +140,8 @@ ephy_tabs_menu_set_window (EphyTabsMenu *menu, EphyWindow *window)
 			         G_CALLBACK (tab_added_cb), menu, 0);
 	g_signal_connect_object (notebook, "tab_removed",
 			         G_CALLBACK (tab_removed_cb), menu, 0);
+	g_signal_connect_object (notebook, "tabs_reordered",
+				 G_CALLBACK (tabs_reordered_cb), menu, 0);
 }
 
 static void
@@ -235,7 +234,7 @@ tab_set_action_accelerator (GtkActionGroup *action_group,
 			    guint tab_number)
 {
 	const char *action_name, *action_group_name;
-	char *accel_path = NULL;
+	char *accel_path;
 	char accel[7];
 	gint accel_number;
 	guint accel_key;
@@ -269,6 +268,8 @@ tab_set_action_accelerator (GtkActionGroup *action_group,
 	{
 		gtk_accel_map_change_entry (accel_path, 0, 0, TRUE);
 	}
+
+	g_free (accel_path);
 }
 
 void
@@ -279,7 +280,6 @@ ephy_tabs_menu_update (EphyTabsMenu *menu)
 	EphyTab *tab;
 	GtkAction *action;
 	guint i = 0;
-	guint num = 0;
 	GList *tabs = NULL, *l;
 
 	g_return_if_fail (EPHY_IS_TABS_MENU (menu));
@@ -294,8 +294,7 @@ ephy_tabs_menu_update (EphyTabsMenu *menu)
 
 	tabs = ephy_window_get_tabs (p->window);
 
-	num = g_list_length (tabs);
-	if (num == 0) return;
+	if (g_list_length (tabs) == 0) return;
 
 	p->ui_id = gtk_ui_manager_new_merge_id (merge);
 
@@ -304,7 +303,6 @@ ephy_tabs_menu_update (EphyTabsMenu *menu)
 		const char *action_name;
 		char *name;
 
-
 		tab = (EphyTab *) l->data;
 		action = GTK_ACTION (ephy_tab_get_action (tab));
 		action_name = gtk_action_get_name (action);
