@@ -15,13 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.112 2004/02/21 09:03:03 marco Exp $
+ *  $Id: window-commands.c,v 1.115.4.8 2004/08/04 13:53:14 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include "ephy-embed-shell.h"
+#include "ephy-embed-single.h"
 #include "ephy-shell.h"
 #include "ephy-embed-factory.h"
 #include "ephy-embed-persist.h"
@@ -73,11 +75,10 @@ void
 window_cmd_file_print_setup (GtkAction *action,
 			     EphyWindow *window)
 {
-	EphyDialog *dialog;
+	EphyEmbedSingle *single;
 
-	dialog = EPHY_DIALOG (ephy_shell_get_print_setup_dialog (ephy_shell));
-
-	ephy_dialog_show (dialog);
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
+	ephy_embed_single_print_setup (single);
 }
 
 void
@@ -85,18 +86,11 @@ window_cmd_file_print_preview (GtkAction *action,
 			       EphyWindow *window)
 {
 	EphyEmbed *embed;
-	EmbedPrintInfo *info;
 
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
-	info = ephy_print_get_print_info ();
-	info->preview = TRUE;
-
-	ephy_embed_print (embed, info);
-
-	ephy_print_info_free (info);
-
+	ephy_embed_set_print_preview_mode (embed, TRUE);
 	ephy_window_set_print_preview (window, TRUE);
 }
 
@@ -104,7 +98,12 @@ void
 window_cmd_file_print (GtkAction *action,
 		       EphyWindow *window)
 {
-	ephy_window_print (window);
+	EphyEmbed *embed;
+
+	embed = ephy_window_get_active_embed (window);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	ephy_embed_print (embed);
 }
 
 void
@@ -271,8 +270,8 @@ window_cmd_view_reload (GtkAction *action,
 
 	ephy_embed_activate (embed);
 
-	ephy_embed_reload (embed, force ? EMBED_RELOAD_NORMAL
-					: EMBED_RELOAD_FORCE);
+	ephy_embed_reload (embed, force ? EMBED_RELOAD_FORCE
+					: EMBED_RELOAD_NORMAL);
 }
 
 void
@@ -362,23 +361,26 @@ window_cmd_file_bookmark_page (GtkAction *action,
 }
 
 static void
-open_response_cb (GtkDialog *dialog, gint response, EphyWindow *window)
+open_response_cb (GtkDialog *dialog, int response, EphyWindow *window)
 {
-	if (response == EPHY_RESPONSE_OPEN)
+	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		char *uri, *converted;
 
 		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog));
-		converted = g_filename_to_utf8 (uri, -1, NULL, NULL, NULL);
-
-		if (converted != NULL)
+		if (uri != NULL)
 		{
-			ephy_window_load_url(window, converted);
-		}
-
-		g_free (converted);
-		g_free (uri);
-        }
+			converted = g_filename_to_utf8 (uri, -1, NULL, NULL, NULL);
+	
+			if (converted != NULL)
+			{
+				ephy_window_load_url (window, converted);
+			}
+	
+			g_free (converted);
+			g_free (uri);
+	        }
+	}
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
@@ -583,36 +585,6 @@ window_cmd_edit_find_prev (GtkAction *action,
 	ephy_embed_find_next (embed, TRUE);
 }
 
-void
-window_cmd_view_bookmarks_bar (GtkAction *action,
-			       EphyWindow *window)
-{
-	gboolean active;
-
-	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_WINDOWS_SHOW_BOOKMARKS_BAR, active);
-}
-
-void
-window_cmd_view_toolbar (GtkAction *action,
-			 EphyWindow *window)
-{
-	gboolean active;
-
-	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_WINDOWS_SHOW_TOOLBARS, active);
-}
-
-void
-window_cmd_view_statusbar (GtkAction *action,
-			   EphyWindow *window)
-{
-	gboolean active;
-
-	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_WINDOWS_SHOW_STATUSBAR, active);
-}
-
 void
 window_cmd_view_fullscreen (GtkAction *action,
 			    EphyWindow *window)
@@ -730,6 +702,11 @@ editor_can_open_uri (char *address)
 		gnome_vfs_uri_unref (uri);
 	}
 
+	if (app)
+	{
+		gnome_vfs_mime_application_free (app);
+	}
+
 	return result;
 }
 
@@ -791,6 +768,8 @@ window_cmd_view_page_source (GtkAction *action,
 	{
 		save_temp_source (embed);
 	}
+
+	g_free (address);
 }
 
 void
@@ -812,6 +791,7 @@ window_cmd_edit_personal_data (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_pdm_dialog (ephy_shell));
+	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -823,6 +803,7 @@ window_cmd_edit_prefs (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_prefs_dialog (ephy_shell));
+	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -927,7 +908,6 @@ window_cmd_help_about (GtkAction *action,
 {
 	static GtkWidget *about = NULL;
 	GtkWidget** ptr;
-	GdkPixbuf *icon;
 	const char *icon_path;
 	GdkPixbuf *logo = NULL;
 	GtkIconTheme *icon_theme;
@@ -985,6 +965,8 @@ window_cmd_help_about (GtkAction *action,
 		       strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 		       logo);
 
+	gtk_window_set_icon (GTK_WINDOW (about), logo);
+
 	if (logo != NULL)
 	{
 		g_object_unref (logo);
@@ -993,13 +975,6 @@ window_cmd_help_about (GtkAction *action,
 	gtk_window_set_transient_for (GTK_WINDOW (about),
 				      GTK_WINDOW (window));
 
-	icon = gtk_widget_render_icon (about,
-				       GNOME_STOCK_ABOUT,
-				       GTK_ICON_SIZE_MENU,
-				       NULL);
-	gtk_window_set_icon (GTK_WINDOW (about), icon);
-	g_object_unref(icon);
-
 	ptr = &about;
 	g_object_add_weak_pointer (G_OBJECT (about), (gpointer *)ptr);
 	gtk_widget_show (about);
@@ -1058,7 +1033,8 @@ window_cmd_tabs_move_left  (GtkAction *action,
 		GtkWidget *child;
 
 		child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page);
-		ephy_notebook_move_page (EPHY_NOTEBOOK (notebook), NULL, child, page - 1);
+		ephy_notebook_move_tab (EPHY_NOTEBOOK (notebook), NULL,
+					EPHY_TAB (child), page - 1);
 	}
 }
 
@@ -1078,7 +1054,8 @@ void window_cmd_tabs_move_right (GtkAction *action,
 		GtkWidget *child;
 
 		child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page);
-		ephy_notebook_move_page (EPHY_NOTEBOOK (notebook), NULL, child, page + 1);
+		ephy_notebook_move_tab (EPHY_NOTEBOOK (notebook), NULL,
+					EPHY_TAB (child), page + 1);
 	}
 }
 
@@ -1087,19 +1064,18 @@ window_cmd_tabs_detach  (GtkAction *action,
 			 EphyWindow *window)
 {
 	EphyTab *tab;
-	GtkWidget *src_page, *nb;
+	GtkWidget *nb;
 	EphyWindow *new_win;
 
 	nb = ephy_window_get_notebook (window);
 	if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) <= 1) return;
 
 	tab = ephy_window_get_active_tab (window);
-	src_page = GTK_WIDGET (ephy_tab_get_embed (tab));
+
 	new_win = ephy_window_new ();
-	ephy_notebook_move_page (EPHY_NOTEBOOK (ephy_window_get_notebook (window)),
+	ephy_notebook_move_tab (EPHY_NOTEBOOK (ephy_window_get_notebook (window)),
 				EPHY_NOTEBOOK (ephy_window_get_notebook (new_win)),
-				src_page, 0);
-	ephy_tab_set_window (tab, new_win);
+				tab, 0);
 	gtk_widget_show (GTK_WIDGET (new_win));
 }
 
